Modules
- add_
custom_ game - browse_
nexus - Browse Nexus view — four tabs (Top / Month / Collections / Search), result grid, and a minimal install-from-browse flow.
- collections
- data_
tab - diagnostics
- downloads
- executables
- fomod_
wizard - game_
picker - mod_
details - Right-rail “mod details” panel — rendered at the bottom of the left nav sidebar when a mod with Nexus metadata is selected in the mod list.
- mod_
list - overwrite
- save_
details - Save snapshot detail panel — rendered at the bottom of the left sidebar when a save snapshot is selected in the saves view.
- saves
- selectable_
text - settings
- sidebar
- tabs
- tools
- wabbajack